==> istio-model-v1alpha3-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl<A extends EnvoyFilterEnvoyConfigObjectMatchListenerFluent<A>> extends BaseFluent<A> implements EnvoyFilterEnvoyConfigObjectMatchListenerFluent<A>{
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl() {
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl(EnvoyFilterEnvoyConfigObjectMatchListener instance) {
    this.withListener(instance.getListener()); 
  }
  private EnvoyFilterListenerMatchBuilder listener;
  
  /**
   * This method has been deprecated, please use method buildListener instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterListenerMatch getListener() {
    return this.listener!=null ?this.listener.build():null;
  }
  public EnvoyFilterListenerMatch buildListener() {
    return this.listener!=null ?this.listener.build():null;
  }
  public A withListener(EnvoyFilterListenerMatch listener) {
    _visitables.get("listener").remove(this.listener);
    if (listener!=null){ this.listener= new EnvoyFilterListenerMatchBuilder(listener); _visitables.get("listener").add(this.listener);} else { this.listener = null; _visitables.get("listener").remove(this.listener); } return (A) this;
  }
  public Boolean hasListener() {
    return this.listener != null;
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluent.ListenerNested<A> withNewListener() {
    return new EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.ListenerNestedImpl();
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluent.ListenerNested<A> withNewListenerLike(EnvoyFilterListenerMatch item) {
    return new EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.ListenerNestedImpl(item);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluent.ListenerNested<A> editListener() {
    return withNewListenerLike(getListener());
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluent.ListenerNested<A> editOrNewListener() {
    return withNewListenerLike(getListener() != null ? getListener(): new EnvoyFilterListenerMatchBuilder().build());
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluent.ListenerNested<A> editOrNewListenerLike(EnvoyFilterListenerMatch item) {
    return withNewListenerLike(getListener() != null ? getListener(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl that = (EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl) o;
    if (listener != null ? !listener.equals(that.listener) :that.listener != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(listener,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (listener != null) { sb.append("listener:"); sb.append(listener); }
    sb.append("}");
    return sb.toString();
  }
  class ListenerNestedImpl<N> extends EnvoyFilterListenerMatchFluentImpl<EnvoyFilterEnvoyConfigObjectMatchListenerFluent.ListenerNested<N>> implements EnvoyFilterEnvoyConfigObjectMatchListenerFluent.ListenerNested<N>,Nested<N>{
    ListenerNestedImpl(EnvoyFilterListenerMatch item) {
      this.builder = new EnvoyFilterListenerMatchBuilder(this, item);
    }
    ListenerNestedImpl() {
      this.builder = new EnvoyFilterListenerMatchBuilder(this);
    }
    EnvoyFilterListenerMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.this.withListener(builder.build());
    }
    public N endListener() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl<A extends EnvoyFilterEnvoyConfigObjectMatchListenerFluent<A>> extends BaseFluent<A> implements EnvoyFilterEnvoyConfigObjectMatchListenerFluent<A>{
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl() {
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl(EnvoyFilterEnvoyConfigObjectMatchListener instance) {
    if (instance != null) {
      this.withListener(instance.getListener());
    }
  }
  private EnvoyFilterListenerMatchBuilder listener;
  
  /**
   * This method has been deprecated, please use method buildListener instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterListenerMatch getListener() {
    return this.listener!=null ?this.listener.build():null;
  }
  public EnvoyFilterListenerMatch buildListener() {
    return this.listener!=null ?this.listener.build():null;
  }
  public A withListener(EnvoyFilterListenerMatch listener) {
    _visitables.get("listener").remove(this.listener);
    if (listener!=null){ this.listener= new EnvoyFilterListenerMatchBuilder(listener); _visitables.get("listener").add(this.listener);} else { this.listener = null; _visitables.get("listener").remove(this.listener); } return (A) this;
  }
  public Boolean hasListener() {
    return this.listener != null;
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.ListenerNested<A> withNewListener() {
    return new EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.ListenerNestedImpl();
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.ListenerNested<A> withNewListenerLike(EnvoyFilterListenerMatch item) {
    return new EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.ListenerNestedImpl(item);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.ListenerNested<A> editListener() {
    return withNewListenerLike(getListener());
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.ListenerNested<A> editOrNewListener() {
    return withNewListenerLike(getListener() != null ? getListener(): new EnvoyFilterListenerMatchBuilder().build());
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.ListenerNested<A> editOrNewListenerLike(EnvoyFilterListenerMatch item) {
    return withNewListenerLike(getListener() != null ? getListener(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl that = (EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl) o;
    if (!java.util.Objects.equals(listener, that.listener)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(listener,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (listener != null) { sb.append("listener:"); sb.append(listener); }
    sb.append("}");
    return sb.toString();
  }
  class ListenerNestedImpl<N> extends EnvoyFilterListenerMatchFluentImpl<EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.ListenerNested<N>> implements EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.ListenerNested<N>,Nested<N>{
    ListenerNestedImpl(EnvoyFilterListenerMatch item) {
      this.builder = new EnvoyFilterListenerMatchBuilder(this, item);
    }
    ListenerNestedImpl() {
      this.builder = new EnvoyFilterListenerMatchBuilder(this);
    }
    EnvoyFilterListenerMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchListenerFluentImpl.this.withListener(builder.build());
    }
    public N endListener() {
      return and();
    }
    
  }
  
}
